==> SemiParBIVProbit_3.2-13.1.tar.gz: SemiParBIVProbit/man/est.prev.Rd <==
\name{est.prev}
\alias{est.prev}

\title{Estimated overall prevalence from sample selection model}

\description{ 
\code{est.prev} can be used to calculate the overall estimated prevalence from a sample selection model, with corresponding confidence intervals
obtained using the delta method.}



\usage{

est.prev(x, sig.lev = 0.05, sw = NULL, naive = FALSE)

}

\arguments{ 

\item{x}{A fitted \code{SemiParBIVProbit} object as produced by \code{SemiParBIVProbit()}.}
 
\item{sig.lev}{Significance level.} 

\item{sw}{Survey weights.} 

\item{naive}{If \code{FALSE} then the prevalence is calculated using the (naive/classic imputation) probit model. This option has 
             been introduced to compare adjusted (for non-random sample selection) and unadjusted estimates.} 


}


\details{

\code{est.prev} estimates the overall prevalence of a disease (e.g., HIV) when there are missing values that are not at random. 

}



\value{

\item{res}{It returns three values: lower confidence interval limit, estimated prevalence and upper confidence interval limit.}
\item{sig.lev}{Significance level used.}

}




\author{

Maintainer: Giampiero Marra \email{giampiero.marra@ucl.ac.uk}

}

\references{

McGovern M.E., Barnighausen T., Marra G. and Radice R. (2015), On the Assumption of Joint Normality in Selection Models: A Copula Based Approach Applied to Estimating HIV Prevalence. \emph{Epidemiology}.

}




\seealso{
\code{\link{SemiParBIVProbit-package}}, \code{\link{SemiParBIVProbit}}, \code{\link{summary.SemiParBIVProbit}}  
}

\examples{
## see examples for SemiParBIVProbit
}

\keyword{semiparametric bivariate probit modelling} 
\keyword{bivariate probit model} 
\keyword{prevalence} 
\keyword{delta method}
\keyword{non-random sample selection}

==> SemiParBIVProbit_3.3.tar.gz: SemiParBIVProbit/man/est.prev.Rd <==
\name{est.prev}
\alias{est.prev}

\title{Estimated overall prevalence from sample selection model}

\description{ 
\code{est.prev} can be used to calculate the overall estimated prevalence from a sample selection model, with corresponding confidence intervals
obtained using the delta method.}



\usage{

est.prev(x, sig.lev = 0.05, sw = NULL, naive = FALSE)

}

\arguments{ 

\item{x}{A fitted \code{SemiParBIVProbit} object as produced by \code{SemiParBIVProbit()}.}
 
\item{sig.lev}{Significance level.} 

\item{sw}{Survey weights.} 

\item{naive}{If \code{FALSE} then the prevalence is calculated using the (naive/classic imputation) probit model. This option has 
             been introduced to compare adjusted (for non-random sample selection) and unadjusted estimates.} 


}


\details{

\code{est.prev} estimates the overall prevalence of a disease (e.g., HIV) when there are missing values that are not at random. 

}



\value{

\item{res}{It returns three values: lower confidence interval limit, estimated prevalence and upper confidence interval limit.}
\item{sig.lev}{Significance level used.}

}




\author{

Maintainer: Giampiero Marra \email{giampiero.marra@ucl.ac.uk}

}

\references{

McGovern M.E., Barnighausen T., Marra G. and Radice R. (2015), On the Assumption of Joint Normality in Selection Models: A Copula Approach Applied to Estimating HIV Prevalence. \emph{Epidemiology}, 26(2), 229-237.

}




\seealso{
\code{\link{SemiParBIVProbit-package}}, \code{\link{SemiParBIVProbit}}, \code{\link{summary.SemiParBIVProbit}}  
}

\examples{
## see examples for SemiParBIVProbit
}

\keyword{semiparametric bivariate probit modelling} 
\keyword{bivariate probit model} 
\keyword{prevalence} 
\keyword{delta method}
\keyword{non-random sample selection}
